@@ -113,6 +113,7 @@ __all__ = (
     "DescribeHostReservationsPaginatorName",
     "DescribeHostsPaginatorName",
     "DescribeIamInstanceProfileAssociationsPaginatorName",
+    "DescribeImagesPaginatorName",
     "DescribeImportImageTasksPaginatorName",
     "DescribeImportSnapshotTasksPaginatorName",
     "DescribeInstanceCreditSpecificationsPaginatorName",
@@ -667,6 +668,7 @@ DescribeHostsPaginatorName = Literal["describe_hosts"]
 DescribeIamInstanceProfileAssociationsPaginatorName = Literal[
     "describe_iam_instance_profile_associations"
 ]
+DescribeImagesPaginatorName = Literal["describe_images"]
 DescribeImportImageTasksPaginatorName = Literal["describe_import_image_tasks"]
 DescribeImportSnapshotTasksPaginatorName = Literal["describe_import_snapshot_tasks"]
 DescribeInstanceCreditSpecificationsPaginatorName = Literal[
@@ -2174,6 +2176,7 @@ ServiceName = Literal[
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
@@ -2376,6 +2379,7 @@ PaginatorName = Literal[
     "describe_host_reservations",
     "describe_hosts",
     "describe_iam_instance_profile_associations",
+    "describe_images",
     "describe_import_image_tasks",
     "describe_import_snapshot_tasks",
     "describe_instance_credit_specifications",
